@@ -18,15 +18,15 @@
  FIXME : should check constant names !
 """
 
-__revision__ = "$Id: base.py,v 1.54 2005/04/12 09:55:03 syt Exp $"
+__revision__ = "$Id: base.py,v 1.56 2005/05/27 09:17:14 syt Exp $"
 
 from logilab.common import astng
 from logilab.common.ureports import Table
 
-from logilab.pylint.interfaces import IASTNGChecker
-from logilab.pylint.reporters import diff_string
-from logilab.pylint.checkers import BaseChecker
-from logilab.pylint.checkers.utils import are_exclusive
+from pylint.interfaces import IASTNGChecker
+from pylint.reporters import diff_string
+from pylint.checkers import BaseChecker
+from pylint.checkers.utils import are_exclusive
 
 import re
 
@@ -277,8 +277,7 @@ functions, methods
         """most of the work is done here on close:
         checks for max returns, branch, return in __init__
         """
-        is_method = node.is_method()
-        if is_method and node.name == '__init__' and self._returns.pop():
+        if node.is_method() and node.name == '__init__' and self._returns.pop():
             self.add_message('E0101', node=node)
 
     def visit_return(self, node):
