@@ -17,13 +17,13 @@
 """
 from __future__ import generators
 
-__revision__ = "$Id: classes.py,v 1.58 2005/04/08 14:07:37 syt Exp $"
+__revision__ = "$Id: classes.py,v 1.61 2005/05/27 09:19:51 syt Exp $"
 
 from logilab.common import astng
 
-from logilab.pylint.interfaces import IASTNGChecker
-from logilab.pylint.checkers import BaseChecker
-from logilab.pylint.checkers.utils import is_abstract, is_interface, \
+from pylint.interfaces import IASTNGChecker
+from pylint.checkers import BaseChecker
+from pylint.checkers.utils import is_abstract, is_interface, \
      is_exception, is_metaclass, get_nodes_from_class
 
 
@@ -176,7 +176,11 @@ class should be ignored. A mixin class is detected if its name ends with \
                                           'setUp'):
                         self.add_message('W0201', args=attr, node=node)
                 except astng.NotFoundError:
-                    self.add_message('W0201', args=attr, node=node)
+                    if not attr in cnode.locals:
+                        try:
+                            cnode.get_ancestor_for_class_attribute(attr)
+                        except astng.NotFoundError:
+                            self.add_message('W0201', args=attr, node=node)
         # check access to existant members on non metaclass classes
         accessed = self._accessed.pop()
         if not cnode.metaclass and (not self.config.ignore_mixin_members or 
@@ -236,7 +240,7 @@ class should be ignored. A mixin class is detected if its name ends with \
             if attr in ('__dict__', '__class__', '__doc__'):
                 continue
             # is it an instance attribute ?
-            if node.instance_attrs.has_key(attr):
+            if node.instance_attrs.has_key(attr) and not attr in node.locals:
                 try:
                     node.get_ancestor_for_attribute(attr)
                     # an ancestor is defining this attribute, skip it
