@@ -20,14 +20,14 @@
  FIXME: missing 13, 15, 16
 """
 
-__revision__ = "$Id: design_analysis.py,v 1.7 2005/01/19 16:09:45 syt Exp $"
+__revision__ = "$Id: design_analysis.py,v 1.9 2005/05/27 09:17:13 syt Exp $"
 
 from logilab.common.astng import Function
 from logilab.common.astng.utils import get_interfaces
 
-from logilab.pylint.interfaces import IASTNGChecker
-from logilab.pylint.checkers import BaseChecker
-from logilab.pylint.checkers.utils import is_interface, is_exception, \
+from pylint.interfaces import IASTNGChecker
+from pylint.checkers import BaseChecker
+from pylint.checkers.utils import is_interface, is_exception, \
      is_abstract, is_metaclass
 
 def class_is_abstract(klass):
@@ -310,7 +310,7 @@ class MisdesignChecker(BaseChecker):
     def _inc_branch(self, branchsnum=1):
         """increments the branchs counter"""
         branchs = self._branchs
-        for i in range(len(branchs)):
+        for i in xrange(len(branchs)):
             branchs[i] += branchsnum
 
     # FIXME: make a nice report...
