@@ -16,13 +16,13 @@
 exceptions checkers for Python code
 """
 
-__revision__ = '$Id: exceptions.py,v 1.17 2005/02/16 14:48:29 syt Exp $'
+__revision__ = '$Id: exceptions.py,v 1.18 2005/04/15 10:40:10 syt Exp $'
 
 from logilab.common import astng
 
-from logilab.pylint.checkers import BaseChecker
-from logilab.pylint.checkers.utils import is_empty, get_names
-from logilab.pylint.interfaces import IASTNGChecker
+from pylint.checkers import BaseChecker
+from pylint.checkers.utils import is_empty, get_names
+from pylint.interfaces import IASTNGChecker
 
 MSGS = {
     'W0701': ('Raise a string exception',
