@@ -22,7 +22,7 @@ http://www.python.org/doc/essays/styleguide.html
 Some parts of the process_token method is based from The Tab Nanny std module.
 """
 
-__revision__ = "$Id: format.py,v 1.47 2005/02/24 16:58:35 syt Exp $"
+__revision__ = "$Id: format.py,v 1.48 2005/04/15 10:40:11 syt Exp $"
 
 from os import linesep
 import re
@@ -32,8 +32,8 @@ if not hasattr(tokenize, 'NL'):
 
 from logilab.common.textutils import pretty_match
 
-from logilab.pylint.interfaces import IRawChecker, IASTNGChecker
-from logilab.pylint.checkers import BaseRawChecker
+from pylint.interfaces import IRawChecker, IASTNGChecker
+from pylint.checkers import BaseRawChecker
 
 MSGS = {
     'C0301': ('Line too long (%s/%s)',
