@@ -16,16 +16,16 @@
 imports checkers for Python code
 """
 
-__revision__ = "$Id: imports.py,v 1.41 2005/02/09 09:40:04 syt Exp $"
+__revision__ = "$Id: imports.py,v 1.42 2005/04/15 10:40:11 syt Exp $"
 
 from logilab.common import get_cycles, astng
 from logilab.common.modutils import is_standard_module, is_relative, \
      get_module_part
 from logilab.common.ureports import VerbatimText, Paragraph
 
-from logilab.pylint.interfaces import IASTNGChecker
-from logilab.pylint.checkers import BaseChecker, EmptyReport
-from logilab.pylint.checkers.utils import are_exclusive
+from pylint.interfaces import IASTNGChecker
+from pylint.checkers import BaseChecker, EmptyReport
+from pylint.checkers.utils import are_exclusive
 
 def get_first_import(context_dict, name, base):
     """return the node where [base.]<name> is imported or None if not found
