@@ -17,12 +17,12 @@
 Check source code is ascii only or has an encoding declaration (PEP 263)
 """
 
-__revision__ = '$Id: misc.py,v 1.17 2005/01/20 15:12:55 syt Exp $'
+__revision__ = '$Id: misc.py,v 1.18 2005/04/15 10:40:11 syt Exp $'
 
 import re
 
-from logilab.pylint.interfaces import IRawChecker
-from logilab.pylint.checkers import BaseChecker
+from pylint.interfaces import IRawChecker
+from pylint.checkers import BaseChecker
 
 def is_ascii(string):
     """return true if non ascii characters are detected in the given string
