@@ -16,7 +16,7 @@
 Raw metrics checker
 """
 
-__revision__ = "$Id: raw_metrics.py,v 1.13 2005/01/20 15:12:55 syt Exp $"
+__revision__ = "$Id: raw_metrics.py,v 1.14 2005/04/15 10:40:11 syt Exp $"
 
 import tokenize
 
@@ -26,9 +26,9 @@ import tokenize
 
 from logilab.common.ureports import Table
 
-from logilab.pylint.interfaces import IRawChecker
-from logilab.pylint.checkers import BaseRawChecker, EmptyReport
-from logilab.pylint.reporters import diff_string
+from pylint.interfaces import IRawChecker
+from pylint.checkers import BaseRawChecker, EmptyReport
+from pylint.reporters import diff_string
 
  
 class RawMetricsChecker(BaseRawChecker):
