@@ -18,15 +18,15 @@
 """
 from __future__ import generators
 
-__revision__ = '$Id: similar.py,v 1.10 2005/04/07 15:44:45 syt Exp $'
+__revision__ = '$Id: similar.py,v 1.11 2005/04/15 10:40:11 syt Exp $'
 
 import sys
 
 from logilab.common.compat import Set, izip, sum, enumerate
 from logilab.common.ureports import Table
 
-from logilab.pylint.interfaces import IRawChecker
-from logilab.pylint.checkers import BaseChecker, table_lines_from_stats
+from pylint.interfaces import IRawChecker
+from pylint.checkers import BaseChecker, table_lines_from_stats
 
 
 class Similar:
