@@ -16,16 +16,16 @@
 variables checkers for Python code
 """
 
-__revision__ = "$Id: variables.py,v 1.45 2005/04/14 09:32:09 syt Exp $"
+__revision__ = "$Id: variables.py,v 1.50 2005/04/19 18:03:17 syt Exp $"
 
 from copy import copy
 
 from logilab.common import astng
 
-from logilab.pylint.interfaces import IASTNGChecker
-from logilab.pylint.checkers import BaseChecker
-from logilab.pylint.checkers.utils import is_interface, is_error, is_builtin, \
-     is_native_builtin, is_abstract, are_exclusive, get_nodes_from_class
+from pylint.interfaces import IASTNGChecker
+from pylint.checkers import BaseChecker
+from pylint.checkers.utils import is_interface, is_error, is_builtin, \
+     is_abstract, are_exclusive, get_nodes_from_class
 
     
 MSGS = {
@@ -74,6 +74,12 @@ __init__ files.'}),
                  'metavar' : '<comma separated list>',
                  'help' : 'List of variable names used for dummy variables \
 (i.e. not used).'}),
+               ("additional-builtins",
+                {'default': (), 'type' : 'csv',
+                 'metavar' : '<comma separated list>',
+                 'help' : 'List of additional names supposed to be defined in \
+builtins. Remember that you should avoid to define new builtins when possible.'
+                 }),
                )
     def __init__(self, linter=None):
         BaseChecker.__init__(self, linter)
@@ -85,7 +91,7 @@ __init__ files.'}),
         """
         self._to_consume = [(copy(node.locals), {}, 'module')]
         for name, stmt in node.locals.items():
-            if name != '__builtins__' and is_native_builtin(name):
+            if self.is_builtin(name):
                 self.add_message('W0622', args=name, node=stmt)
         
     def leave_module(self, node):
@@ -139,7 +145,7 @@ __init__ files.'}),
             if globs.has_key(name) and not isinstance(stmt, astng.Global):
                 line = globs[name].lineno
                 self.add_message('W0621', args=(name, line), node=stmt)
-            elif is_native_builtin(name):
+            elif self.is_builtin(name):
                 self.add_message('W0622', args=name, node=stmt)
                 
         self._to_consume.append((copy(node.locals), {}, 'function'))
@@ -221,7 +227,7 @@ __init__ files.'}),
                 # is protected by a try: except NameError:
                 if def_stmt and frame is consumed[name].get_frame() and \
                        stmt.source_line() <= def_stmt.source_line() and \
-                       not list_comp_var(node) and \
+                       not is_defined_before(node) and \
                        not are_exclusive(stmt, def_stmt):
                     self.add_message('E0601', args=name, node=node)
                 break
@@ -230,9 +236,15 @@ __init__ files.'}),
         else:
             # we have not found the name, if it isn't a builtin, that's an
             # undefined name !
-            if not is_builtin(name):
+            if not self.is_builtin(name):
                 self._to_consume[-1][1][name] = 1
                 self.add_message('E0602', args=name, node=stmt)
+                
+    def is_builtin(self, name):
+        """return True if the name is defined in the native builtin or
+        in the user specific builtins
+        """
+        return is_builtin(name) or name in self.config.additional_builtins
 
 try:
     # python >= 2.4
@@ -240,18 +252,37 @@ try:
 except AttributeError:
     COMP_NODE_TYPES = astng.ListComp
     
-def list_comp_var(var_node, comp_node_types=COMP_NODE_TYPES):
-    """return True if the variable node is defined by a parent list
-    comprehension
+def is_defined_before(var_node, comp_node_types=COMP_NODE_TYPES):
+    """return True if the variable node is defined by a parent node (list
+    or generator comprehension, lambda) or in a previous sibling node
+    one the same line (statement_defining ; statement_using)
     """
-    _node = var_node.parent
-    # FIXME: to finish !!!
+    varname = var_node.name
+    _node = start = var_node.parent
     while _node:
         if isinstance(_node, comp_node_types):
             for ass_node in get_nodes_from_class(_node, astng.AssName):
-                if ass_node.name == var_node.name:
+                if ass_node.name == varname:
                     return True
+        elif isinstance(_node, (astng.Lambda, astng.Function)):
+            if varname in _node.argnames:
+                return True
+            if getattr(_node, 'name', None) == varname:
+                return True
+            break
         _node = _node.parent
+    stmt = var_node.get_statement()
+    _node = stmt.previous_sibling()
+    lineno = stmt.lineno
+    while _node and _node.lineno == lineno:
+        for ass_node in get_nodes_from_class(_node, astng.AssName):
+            if ass_node.name == varname:
+                return True
+        for imp_node in get_nodes_from_class(_node, (astng.From,
+                                                     astng.Import)):
+            if varname in [name[1] or name[0] for name in imp_node.names]:
+                return True
+        _node = _node.previous_sibling()
     return False
 
 def is_func_default(node):
