@@ -1,7 +1,7 @@
 from logilab.common import astng
 
-from logilab.pylint.interfaces import IASTNGChecker
-from logilab.pylint.checkers import BaseChecker
+from pylint.interfaces import IASTNGChecker
+from pylint.checkers import BaseChecker
 
 class MyASTNGChecker(BaseChecker):
     """add member attributes defined using my own "properties" function
