@@ -27,12 +27,12 @@
   Display help messages about given message identifiers and exit.
 """
 
-__revision__ = "$Id: lint.py,v 1.93 2005/04/11 10:47:45 syt Exp $"
+__revision__ = "$Id: lint.py,v 1.97 2005/05/27 09:16:35 syt Exp $"
 
 from __future__ import nested_scopes
 
 # import this first to avoid further builtins pollution possibilities
-from logilab.pylint.checkers import utils
+from pylint.checkers import utils
 
 import sys
 import os
@@ -40,7 +40,8 @@ import re
 import tokenize
 from os.path import dirname, basename, splitext, exists, isdir, join, normpath
 
-from logilab.common.configuration import OptionsManagerMixIn, check_yn
+from logilab.common.configuration import OptionsManagerMixIn, \
+     check_yn, check_csv
 from logilab.common.astng import ASTNGManager
 from logilab.common.modutils import modpath_from_file, get_module_files, \
      file_from_modpath
@@ -49,17 +50,17 @@ from logilab.common.textutils import get_csv
 from logilab.common.fileutils import norm_open
 from logilab.common.ureports import Table, Text
 
-from logilab.pylint.utils import UnknownMessage, MessagesHandlerMixIn, \
+from pylint.utils import UnknownMessage, MessagesHandlerMixIn, \
      ReportsHandlerMixIn, MSG_TYPES, sort_checkers
-from logilab.pylint.interfaces import ILinter, IRawChecker, IASTNGChecker
-from logilab.pylint.checkers import BaseRawChecker, EmptyReport, \
+from pylint.interfaces import ILinter, IRawChecker, IASTNGChecker
+from pylint.checkers import BaseRawChecker, EmptyReport, \
      table_lines_from_stats
-from logilab.pylint.reporters.text import TextReporter, TextReporter2, \
+from pylint.reporters.text import TextReporter, TextReporter2, \
      ColorizedTextReporter
-from logilab.pylint.reporters.html import HTMLReporter
-from logilab.pylint import config
+from pylint.reporters.html import HTMLReporter
+from pylint import config
 
-from logilab.pylint.__pkginfo__ import version
+from pylint.__pkginfo__ import version
 
 
 OPTION_RGX = re.compile('#*\s*pylint:(.*)')
@@ -138,6 +139,7 @@ should be a base name, not a path. You may set this option multiple times.'}),
                
                ('reports',
                 {'default': 1, 'type' : 'yn', 'metavar' : '<y_or_n>',
+                 'short': 'r',
                  'group': 'Reports',
                  'help' : 'Tells wether to display a full report or only the\
  messages'}),
@@ -183,6 +185,7 @@ This is used by the global evaluation report (R0004).'}),
 
                ('include-ids',
                 {'type' : 'yn', 'metavar' : '<y_or_n>', 'default' : 0,
+                 'short': 'i',
                  'group': 'Reports',
                  'help' : 'Include message\'s id in output'}),
                
@@ -279,11 +282,12 @@ This is used by the global evaluation report (R0004).'}),
         if opt_name in self._options_methods:
             if value:
                 meth = self._options_methods[opt_name]
-                if isinstance(value, list) :
+                value = check_csv(None, opt_name, value)
+                if isinstance(value, (list, tuple)):
                     for _id in value :
                         meth(_id)
                 else :
-                    meth(_id)
+                    meth(value)
         elif opt_name == 'cache-size':
             self.manager.set_cache_size(int(value))
         elif opt_name in REPORTER_OPT_MAP and check_yn(None, opt_name, value):
@@ -688,7 +692,7 @@ the program to exit'''}),
             ), reporter=reporter, pylintrc=rcfile)
         linter.quiet = quiet
         # register checkers
-        from logilab.pylint import checkers
+        from pylint import checkers
         checkers.initialize(linter)
         # add some help section
         linter.add_help_section('Environment variables', config.ENV_HELP)
@@ -746,7 +750,7 @@ importing analyzed code now'
          
     def cb_generate_manpage(self, *args, **kwargs):
         """optik callback for sample config file generation"""
-        from logilab.pylint import __pkginfo__
+        from pylint import __pkginfo__
         self.linter.generate_manpage(__pkginfo__)
         sys.exit(0)
          
