@@ -16,15 +16,15 @@
 HTML reporter
 """
 
-__revision__ = "$Id: html.py,v 1.12 2005/01/17 17:49:22 syt Exp $"
+__revision__ = "$Id: html.py,v 1.13 2005/04/15 10:40:19 syt Exp $"
 
 import sys
 from cgi import escape
 
 from logilab.common.ureports import HTMLWriter, Section, Table
 
-from logilab.pylint.interfaces import IReporter
-from logilab.pylint.reporters import BaseReporter
+from pylint.interfaces import IReporter
+from pylint.reporters import BaseReporter
 
 
 class HTMLReporter(BaseReporter):
