@@ -16,15 +16,15 @@
 Plain text reporter
 """
 
-__revision__ = "$Id: text.py,v 1.19 2005/01/19 16:09:46 syt Exp $"
+__revision__ = "$Id: text.py,v 1.20 2005/04/15 10:40:19 syt Exp $"
 
 import sys
 
 from logilab.common.ureports import TextWriter
 from logilab.common.textutils import colorize_ansi
 
-from logilab.pylint.interfaces import IReporter
-from logilab.pylint.reporters import BaseReporter
+from pylint.interfaces import IReporter
+from pylint.reporters import BaseReporter
 
 TITLE_UNDERLINES = ['', '=', '-', '.']
 
