@@ -1,8 +1,12 @@
 #!/bin/sh
 
-#PYVER=
+if [ $@ ] ; then
+    PYVERSIONS=$@
+else
+    PYVERSIONS="2.2" "2.3" "2.4"
+fi
 
-for ver in "2.2" "2.3" "2.4"; do  
+for ver in $PYVERSIONS; do  
     echo "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@"
     echo `python$ver -V`
     echo "^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^"
