@@ -15,7 +15,7 @@
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 """functional/non regression tests for pylint"""
 
-__revision__ = '$Id: func_test.py,v 1.31 2005/04/08 13:36:18 syt Exp $'
+__revision__ = '$Id: func_test.py,v 1.35 2005/05/27 10:32:26 syt Exp $'
 
 import unittest
 import sys
@@ -28,8 +28,8 @@ from logilab.common import testlib
 
 from utils import get_tests_info, fix_path, TestReporter
 
-from logilab.pylint.lint import PyLinter
-from logilab.pylint import checkers
+from pylint.lint import PyLinter
+from pylint import checkers
 
 test_reporter = TestReporter()
 linter = PyLinter()
@@ -39,6 +39,7 @@ linter.quiet = 1
 checkers.initialize(linter)
 
 PY23 = sys.version_info >= (2, 3)
+PY24 = sys.version_info >= (2, 4)
 
 
 if linesep != '\n':
@@ -55,7 +56,7 @@ def exception_str(ex):
     """function used to replace default __str__ method of exception instances"""
     return 'in %s\n:: %s' % (ex.file, ', '.join(ex.args))
 
-class LintTest(testlib.TestCase):            
+class LintTestUsingModule(testlib.TestCase):            
 
     def test_functionality(self):
         tocheck = ['input.'+self.module]
@@ -75,7 +76,7 @@ class LintTest(testlib.TestCase):
             # need finalization to restore a correct state
             linter.reporter.finalize()
             ex.file = tocheck
-            ex.__str__ = new.instancemethod(exception_str, ex)
+            ex.__str__ = new.instancemethod(exception_str, ex, None)
             raise
         if self.module.startswith('func_noerror_'):
             expected = ''
@@ -88,10 +89,10 @@ class LintTest(testlib.TestCase):
             self.assertLinesEquals(got, expected)
         except Exception, ex:
             ex.file = tocheck
-            ex.__str__ = new.instancemethod(exception_str, ex)
+            ex.__str__ = new.instancemethod(exception_str, ex, None)
             raise # AssertionError('%s: %r\n!=\n%r\n\n%s' % (self.module, got, expected, ex))
 
-class LintTest2(LintTest):            
+class LintTestUsingFile(LintTestUsingModule):            
                 
     def test_functionality(self):
         tocheck = ['input/' + self.module + '.py']
@@ -125,25 +126,29 @@ def make_tests(filter_rgx):
     tests = []
     for module_file, messages_file in get_tests_info('func_', '.py') + [('nonexistant', 'messages/nonexistant.txt')]:
         # skip those tests with python >= 2.3 since py2.3 detects them by itself
-        if PY23 and module_file  in ("func_unknown_encoding.py",
-                                     ):#"func_nonascii_noencoding.py"):
+        if PY23 and module_file == "func_unknown_encoding.py": #"func_nonascii_noencoding.py"):
+            continue
+        if not PY24 and module_file == "func_noerror_staticmethod_as_decorator.py":
             continue
         if not is_to_run(module_file):
             continue
         base = module_file.replace('func_', '').replace('.py', '')
         dependancies = get_tests_info(base, '.py')
         
-        class LintTestSubclass(LintTest):
+        class LintTestUsingModuleTC(LintTestUsingModule):
             module = module_file.replace('.py', '')
             output = messages_file
             depends = dependancies or None
-        tests.append(LintTestSubclass)
+        tests.append(LintTestUsingModuleTC)
+
+        if MODULES_ONLY:
+            continue
         
-        class LintTest2Subclass(LintTest2):
+        class LintTestUsingFileTC(LintTestUsingFile):
             module = module_file.replace('.py', '')
             output = exists(messages_file + '2') and (messages_file + '2') or messages_file
             depends = dependancies or None
-        tests.append(LintTest2Subclass)
+        tests.append(LintTestUsingFileTC)
         
 ##     # special test for f0003
 ##     module_file, messages_file in get_tests_info('func_f0003', '.pyc')
@@ -152,29 +157,33 @@ def make_tests(filter_rgx):
 ##         output = messages_file
 ##         depends = dependancies or None
 ##     tests.append(LintTestSubclass)
-
+            
+    class LintBuiltinModuleTest(LintTestUsingModule):
+        output = 'messages/builtin_module.txt'
+        module = 'sys'
+        def test_functionality(self):
+            self._test(['sys'])
+    tests.append(LintBuiltinModuleTest)
+    
     if not filter_rgx:
-        class LintBuiltinModuleTest(LintTest):
-            output = 'messages/builtin_module.txt'
-            module = 'sys'
-            def test_functionality(self):
-                self._test(['sys'])
-
-        tests.append(LintBuiltinModuleTest)
-
         # test all features are tested :)    
         tests.append(TestTests)
 
     return tests
 
 FILTER_RGX = None
+MODULES_ONLY = False
 
 def suite():
     return unittest.TestSuite([unittest.makeSuite(test)
                                for test in make_tests(FILTER_RGX)])
 
 if __name__=='__main__':
-    if len(sys.argv) > 1:
+    if '-m' in sys.argv:
+        MODULES_ONLY = True
+        sys.argv.remove('-m')
+    
+    if len(sys.argv) > 1:            
         FILTER_RGX = sys.argv[1]
         del sys.argv[1]
     unittest.main(defaultTest='suite')
