@@ -18,3 +18,7 @@ defined = {defined:__revision__}
 defined[__revision__] = other = 'move this is astng test'
 
 other += '$'
+
+def bad_default(var, default=unknown2):
+    """function with defaut arg's value set to an unexistant name"""
+    print var, default
