@@ -35,3 +35,8 @@ class xyz:
 
     def Youplapoum(self):
         """bad method name"""
+
+
+def nested_args(arg1, (arg21, arg22)):
+    """function with nested arguments"""
+    print arg1, arg21, arg22
