@@ -14,12 +14,12 @@
  http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
-__revision__ = '$Id: unittest_checkers_utils.py,v 1.3 2005/01/12 14:41:38 syt Exp $'
+__revision__ = '$Id: unittest_checkers_utils.py,v 1.5 2005/04/15 16:59:51 syt Exp $'
 
 import unittest
 import sys
 
-from logilab.pylint.checkers import utils
+from pylint.checkers import utils
 try:
     __builtins__.mybuiltin = 2
 except AttributeError:
@@ -27,19 +27,19 @@ except AttributeError:
 
 class UtilsTC(unittest.TestCase):
     
-    def test_is_native_builtin(self):
-        self.assertEquals(utils.is_native_builtin('min'), True)
-        self.assertEquals(utils.is_native_builtin('__path__'), True)
-        self.assertEquals(utils.is_native_builtin('__file__'), True)
-        self.assertEquals(utils.is_native_builtin('whatever'), False)
-        self.assertEquals(utils.is_native_builtin('mybuiltin'), False)
+##     def test_is_native_builtin(self):
+##         self.assertEquals(utils.is_native_builtin('min'), True)
+##         self.assertEquals(utils.is_native_builtin('__path__'), True)
+##         self.assertEquals(utils.is_native_builtin('__file__'), True)
+##         self.assertEquals(utils.is_native_builtin('whatever'), False)
+##         self.assertEquals(utils.is_native_builtin('mybuiltin'), False)
 
     def test_is_builtin(self):
         self.assertEquals(utils.is_builtin('min'), True)
         self.assertEquals(utils.is_builtin('__path__'), True)
         self.assertEquals(utils.is_builtin('__file__'), True)
         self.assertEquals(utils.is_builtin('whatever'), False)
-        self.assertEquals(utils.is_builtin('mybuiltin'), True)
+        self.assertEquals(utils.is_builtin('mybuiltin'), False)
 
 if __name__ == '__main__':
     unittest.main()
