@@ -18,7 +18,7 @@
 main pylint class
 """
 
-__revision__ = "$Id: utils.py,v 1.8 2005/04/08 14:15:52 syt Exp $"
+__revision__ = "$Id: utils.py,v 1.10 2005/04/15 10:40:07 syt Exp $"
 
 from os import linesep
 
@@ -26,7 +26,7 @@ from logilab.common.astng import Module
 from logilab.common.textutils import normalize_text
 from logilab.common.ureports import Section
 
-from logilab.pylint.checkers import EmptyReport
+from pylint.checkers import EmptyReport
 
 class UnknownMessage(Exception):
     """raised when a unregistered message id is encountered"""
@@ -191,12 +191,12 @@ class MessagesHandlerMixIn:
         try:
             if not self._module_msg_cats_state[msg_id[0]]:
                 return False
-        except KeyError:
+        except (KeyError, TypeError):
             if not self._msg_cats_state.get(msg_id[0], True):
                 return False
         try:
             return self._module_msgs_state[msg_id]
-        except KeyError:
+        except (KeyError, TypeError):
             return self._msgs_state.get(msg_id, True)
         
     def add_message(self, msg_id, line=None, node=None, args=None):
@@ -253,11 +253,12 @@ class MessagesHandlerMixIn:
             print checker.name.capitalize()
             print '-' * len(checker.name)
             print
-            print 'Description'
-            print '~~~~~~~~~~~'
-            print linesep.join([line.strip()
-                                for line in checker.__doc__.splitlines()])
-            print
+            if checker.__doc__: # __doc__ is None with -OO
+                print 'Description'
+                print '~~~~~~~~~~~'
+                print linesep.join([line.strip()
+                                    for line in checker.__doc__.splitlines()])
+                print
             if not checker.msgs:
                 continue
             print 'Messages'
